@@ -13,13 +13,11 @@ Including another URLconf
     1. Import the include() function: from django.conf.urls import url, include
     2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
 """
-from django.conf.urls import url, include
 from django.contrib import admin
+from django.urls import include, path
 
-from hordak.views.accounts import AccountListView, AccountCreateView, AccountUpdateView
-from hordak.views.transactions import TransactionsReconcileView
 
 urlpatterns = [
-    url(r"^admin/", admin.site.urls),
-    url(r"^", include("hordak.urls", namespace="hordak")),
+    path("admin/", admin.site.urls),
+    path("", include("hordak.urls", namespace="hordak")),
 ]
