@@ -4,36 +4,45 @@ Design Overview
 
 The core models consist of:
 
-- ``Account`` - Such as 'Accounts Receivable', a bank account, etc. Accounts can be arranged as a tree structure,
+- ``Account`` - Such as 'Accounts Receivable', a bank account, etc.
+  Accounts can be arranged as a tree structure,
   where the balance of the parent account is the summation of the balances of all its children.
 - ``Transaction`` - Represents a movement between accounts. Each transaction must have two or more legs.
-- ``Leg`` - Represents a flow of money into (debit) or out of (credit) a transaction. Debits are represented by
-  negative amounts, and credits by positive amounts. The sum of all a transaction's legs must equal zero. This is
-  enforced with a database constraint.
+- ``Leg`` - Represents a flow of money into (debit) or out of (credit) a transaction.
+  Debits are represented by negative amounts, and credits by positive amounts.
+  The sum of all a transaction's legs must equal zero.
+  This is enforced with a database constraint.
 
 Additionally, there are models which related to the import of external bank statement data:
 
-- ``StatementImport`` - Represents a simple import of zero or more statement lines relating to a specific ``Account``.
+- ``StatementImport`` - Represents a simple import of zero or more statement
+  lines relating to a specific ``Account``.
 - ``StatementLine`` - Represents a statement line. ``StatementLine.create_transaction()`` may be called to
   create a transaction for the statement line.
 """
+from typing import Any
 
 from django.contrib.postgres.fields.array import ArrayField
-from django.contrib.postgres.fields.jsonb import JSONField
+
+
+try:
+    JSONField: Any = None
+    from django.db.models import JSONField
+except ImportError:
+    from django.contrib.postgres.fields.jsonb import JSONField
+
 from django.db import models
-from django.utils import timezone
 from django.db import transaction as db_transaction
+from django.utils import timezone
+from django.utils.translation import gettext_lazy as _
 from django_smalluuid.models import SmallUUIDField, uuid_default
 from djmoney.models.fields import MoneyField
-from moneyed import Money
-
-from mptt.models import MPTTModel, TreeForeignKey, TreeManager
 from model_utils import Choices
+from moneyed import Money
+from mptt.models import MPTTModel, TreeForeignKey, TreeManager
 
-from hordak import defaults
-from hordak import exceptions
-from hordak.defaults import MAX_DIGITS, DECIMAL_PLACES
-
+from hordak import defaults, exceptions
+from hordak.defaults import DECIMAL_PLACES, MAX_DIGITS
 from hordak.utilities.currency import Balance
 
 
@@ -58,7 +67,7 @@ class AccountManager(TreeManager):
 
 
 class Account(MPTTModel):
-    """ Represents an account
+    """Represents an account
 
     An account may have a parent, and may have zero or more children. Only root
     accounts can have a type, all child accounts are assumed to have the same
@@ -86,14 +95,20 @@ class Account(MPTTModel):
 
     TYPES = Choices(
         ("AS", "asset", "Asset"),  # Eg. Cash in bank
-        ("LI", "liability", "Liability"),  # Eg. Loans, bills paid after the fact (in arrears)
+        (
+            "LI",
+            "liability",
+            "Liability",
+        ),  # Eg. Loans, bills paid after the fact (in arrears)
         ("IN", "income", "Income"),  # Eg. Sales, housemate contributions
         ("EX", "expense", "Expense"),  # Eg. Office supplies, paying bills
         ("EQ", "equity", "Equity"),  # Eg. Money from shares
         ("TR", "trading", "Currency Trading"),  # Used to represent currency conversions
     )
-    uuid = SmallUUIDField(default=uuid_default(), editable=False)
-    name = models.CharField(max_length=50)
+    uuid = SmallUUIDField(
+        default=uuid_default(), editable=False, verbose_name=_("uuid")
+    )
+    name = models.CharField(max_length=50, verbose_name=_("name"))
     parent = TreeForeignKey(
         "self",
         null=True,
@@ -101,19 +116,32 @@ class Account(MPTTModel):
         related_name="children",
         db_index=True,
         on_delete=models.CASCADE,
+        verbose_name=_("parent"),
+    )
+    code = models.CharField(max_length=3, null=True, blank=True, verbose_name=_("code"))
+    full_code = models.CharField(
+        max_length=100,
+        db_index=True,
+        unique=True,
+        null=True,
+        blank=True,
+        verbose_name=_("full_code"),
     )
-    code = models.CharField(max_length=3, null=True, blank=True)
-    full_code = models.CharField(max_length=100, db_index=True, unique=True, null=True, blank=True)
     # TODO: Implement this child_code_width field, as it is probably a good idea
     # child_code_width = models.PositiveSmallIntegerField(default=1)
-    type = models.CharField(max_length=2, choices=TYPES, blank=True)
+    type = models.CharField(
+        max_length=2, choices=TYPES, blank=True, verbose_name=_("type")
+    )
     is_bank_account = models.BooleanField(
         default=False,
         blank=True,
         help_text="Is this a bank account. This implies we can import bank "
         "statements into it and that it only supports a single currency",
+        verbose_name=_("is bank account"),
+    )
+    currencies = ArrayField(
+        models.CharField(max_length=3), db_index=True, verbose_name=_("currencies")
     )
-    currencies = ArrayField(models.CharField(max_length=3), db_index=True)
 
     objects = AccountManager.from_queryset(AccountQuerySet)()
 
@@ -122,6 +150,7 @@ class Account(MPTTModel):
 
     class Meta:
         unique_together = (("parent", "code"),)
+        verbose_name = _("account")
 
     def __init__(self, *args, **kwargs):
         super(Account, self).__init__(*args, **kwargs)
@@ -164,10 +193,14 @@ class Account(MPTTModel):
     @classmethod
     def validate_accounting_equation(cls):
         """Check that all accounts sum to 0"""
-        balances = [account.balance(raw=True) for account in Account.objects.root_nodes()]
+        balances = [
+            account.balance(raw=True) for account in Account.objects.root_nodes()
+        ]
         if sum(balances, Balance()) != 0:
             raise exceptions.AccountingEquationViolationError(
-                "Account balances do not sum to zero. They sum to {}".format(sum(balances))
+                "Account balances do not sum to zero. They sum to {}".format(
+                    sum(balances)
+                )
             )
 
     def __str__(self):
@@ -300,7 +333,9 @@ class Account(MPTTModel):
             # the caller wants to reduce the first account and increase the second
             # (which is opposite to the implicit behaviour)
             direction = -1
-        elif self.type == self.TYPES.liability and to_account.type == self.TYPES.expense:
+        elif (
+            self.type == self.TYPES.liability and to_account.type == self.TYPES.expense
+        ):
             # Transfers from liability -> asset accounts should reduce both.
             # For example, moving money from Rent Payable (liability) to your Rent (expense) account
             # should use the funds you've built up in the liability account to pay off the expense account.
@@ -309,8 +344,12 @@ class Account(MPTTModel):
             direction = 1
 
         transaction = Transaction.objects.create(**transaction_kwargs)
-        Leg.objects.create(transaction=transaction, account=self, amount=+amount * direction)
-        Leg.objects.create(transaction=transaction, account=to_account, amount=-amount * direction)
+        Leg.objects.create(
+            transaction=transaction, account=self, amount=+amount * direction
+        )
+        Leg.objects.create(
+            transaction=transaction, account=to_account, amount=-amount * direction
+        )
         return transaction
 
 
@@ -320,7 +359,7 @@ class TransactionManager(models.Manager):
 
 
 class Transaction(models.Model):
-    """ Represents a transaction
+    """Represents a transaction
 
     A transaction is a movement of funds between two accounts. Each transaction
     will have two or more legs, each leg specifies an account and an amount.
@@ -357,19 +396,28 @@ class Transaction(models.Model):
 
     """
 
-    uuid = SmallUUIDField(default=uuid_default(), editable=False)
+    uuid = SmallUUIDField(
+        default=uuid_default(), editable=False, verbose_name=_("uuid")
+    )
     timestamp = models.DateTimeField(
-        default=timezone.now, help_text="The creation date of this transaction object"
+        default=timezone.now,
+        help_text="The creation date of this transaction object",
+        verbose_name=_("timestamp"),
     )
     date = models.DateField(
-        default=timezone.now, help_text="The date on which this transaction occurred"
+        default=timezone.now,
+        help_text="The date on which this transaction occurred",
+        verbose_name=_("date"),
+    )
+    description = models.TextField(
+        default="", blank=True, verbose_name=_("description")
     )
-    description = models.TextField(default="", blank=True)
 
     objects = TransactionManager()
 
     class Meta:
         get_latest_by = "date"
+        verbose_name = _("transaction")
 
     def balance(self):
         return self.legs.sum_to_balance()
@@ -380,8 +428,7 @@ class Transaction(models.Model):
 
 class LegQuerySet(models.QuerySet):
     def sum_to_balance(self):
-        """Sum the Legs of the QuerySet to get a `Balance`_ object
-        """
+        """Sum the Legs of the QuerySet to get a `Balance`_ object"""
         result = self.values("amount_currency").annotate(total=models.Sum("amount"))
         return Balance([Money(r["total"], r["amount_currency"]) for r in result])
 
@@ -400,7 +447,7 @@ class LegManager(models.Manager):
 
 
 class Leg(models.Model):
-    """ The leg of a transaction
+    """The leg of a transaction
 
     Represents a single amount either into or out of a transaction. All legs for a transaction
     must sum to zero, all legs must be of the same currency.
@@ -416,16 +463,31 @@ class Leg(models.Model):
 
     """
 
-    uuid = SmallUUIDField(default=uuid_default(), editable=False)
-    transaction = models.ForeignKey(Transaction, related_name="legs", on_delete=models.CASCADE)
-    account = models.ForeignKey(Account, related_name="legs", on_delete=models.CASCADE)
+    uuid = SmallUUIDField(
+        default=uuid_default(), editable=False, verbose_name=_("uuid")
+    )
+    transaction = models.ForeignKey(
+        Transaction,
+        related_name="legs",
+        on_delete=models.CASCADE,
+        verbose_name=_("transaction"),
+    )
+    account = models.ForeignKey(
+        Account,
+        related_name="legs",
+        on_delete=models.CASCADE,
+        verbose_name=_("account"),
+    )
     amount = MoneyField(
         max_digits=MAX_DIGITS,
         decimal_places=DECIMAL_PLACES,
         help_text="Record debits as positive, credits as negative",
         default_currency=defaults.INTERNAL_CURRENCY,
+        verbose_name=_("amount"),
+    )
+    description = models.TextField(
+        default="", blank=True, verbose_name=_("description")
     )
-    description = models.TextField(default="", blank=True)
 
     objects = LegManager.from_queryset(LegQuerySet)()
 
@@ -456,7 +518,8 @@ class Leg(models.Model):
 
     def account_balance_after(self):
         """Get the balance of the account associated with this leg following the transaction"""
-        # TODO: Consider moving to annotation, particularly once we can count on Django 1.11's subquery support
+        # TODO: Consider moving to annotation,
+        # particularly once we can count on Django 1.11's subquery support
         transaction_date = self.transaction.date
         return self.account.balance(
             leg_query=(
@@ -470,7 +533,8 @@ class Leg(models.Model):
 
     def account_balance_before(self):
         """Get the balance of the account associated with this leg before the transaction"""
-        # TODO: Consider moving to annotation, particularly once we can count on Django 1.11's subquery support
+        # TODO: Consider moving to annotation,
+        # particularly once we can count on Django 1.11's subquery support
         transaction_date = self.transaction.date
         return self.account.balance(
             leg_query=(
@@ -482,6 +546,9 @@ class Leg(models.Model):
             )
         )
 
+    class Meta:
+        verbose_name = _("Leg")
+
 
 class StatementImportManager(models.Manager):
     def get_by_natural_key(self, uuid):
@@ -489,7 +556,7 @@ class StatementImportManager(models.Manager):
 
 
 class StatementImport(models.Model):
-    """ Records an import of a bank statement
+    """Records an import of a bank statement
 
     Attributes:
 
@@ -500,18 +567,28 @@ class StatementImport(models.Model):
 
     """
 
-    uuid = SmallUUIDField(default=uuid_default(), editable=False)
-    timestamp = models.DateTimeField(default=timezone.now)
+    uuid = SmallUUIDField(
+        default=uuid_default(), editable=False, verbose_name=_("uuid")
+    )
+    timestamp = models.DateTimeField(default=timezone.now, verbose_name=_("timestamp"))
     # TODO: Add constraint to ensure destination account expects statements (copy 0007)
-    bank_account = models.ForeignKey(Account, related_name="imports", on_delete=models.CASCADE)
+    bank_account = models.ForeignKey(
+        Account,
+        related_name="imports",
+        on_delete=models.CASCADE,
+        verbose_name=_("bank account"),
+    )
     source = models.CharField(
         max_length=20,
         help_text="A value uniquely identifying where this data came from. "
         'Examples: "csv", "teller.io".',
+        verbose_name=_("source"),
     )
     extra = JSONField(
         default=json_default,
-        help_text="Any extra data relating to the import, probably specific " "to the data source.",
+        help_text="Any extra data relating to the import, probably specific "
+        "to the data source.",
+        verbose_name=_("extra"),
     )
 
     objects = StatementImportManager()
@@ -519,6 +596,9 @@ class StatementImport(models.Model):
     def natural_key(self):
         return (self.uuid,)
 
+    class Meta:
+        verbose_name = _("statementImport")
+
 
 class StatementLineManager(models.Manager):
     def get_by_natural_key(self, uuid):
@@ -526,7 +606,7 @@ class StatementLineManager(models.Manager):
 
 
 class StatementLine(models.Model):
-    """ Records an single imported bank statement line
+    """Records an single imported bank statement line
 
     A StatementLine is purely a utility to aid in the creation of transactions
     (in the process known as reconciliation). StatementLines have no impact on
@@ -547,15 +627,24 @@ class StatementLine(models.Model):
             occurs during reconciliation. See also :meth:`StatementLine.create_transaction()`.
     """
 
-    uuid = SmallUUIDField(default=uuid_default(), editable=False)
-    timestamp = models.DateTimeField(default=timezone.now)
-    date = models.DateField()
-    statement_import = models.ForeignKey(
-        StatementImport, related_name="lines", on_delete=models.CASCADE
+    uuid = SmallUUIDField(
+        default=uuid_default(), editable=False, verbose_name=_("uuid")
     )
-    amount = models.DecimalField(max_digits=MAX_DIGITS, decimal_places=DECIMAL_PLACES)
-    description = models.TextField(default="", blank=True)
-    type = models.CharField(max_length=50, default="")
+    timestamp = models.DateTimeField(default=timezone.now, verbose_name=_("timestamp"))
+    date = models.DateField(verbose_name=_("date"))
+    statement_import = models.ForeignKey(
+        StatementImport,
+        related_name="lines",
+        on_delete=models.CASCADE,
+        verbose_name=_("statement import"),
+    )
+    amount = models.DecimalField(
+        max_digits=MAX_DIGITS, decimal_places=DECIMAL_PLACES, verbose_name=_("amount")
+    )
+    description = models.TextField(
+        default="", blank=True, verbose_name=_("description")
+    )
+    type = models.CharField(max_length=50, default="", verbose_name=_("type"))
     # TODO: Add constraint to ensure transaction amount = statement line amount
     # TODO: Add constraint to ensure one statement line per transaction
     transaction = models.ForeignKey(
@@ -565,9 +654,12 @@ class StatementLine(models.Model):
         null=True,
         help_text="Reconcile this statement line to this transaction",
         on_delete=models.SET_NULL,
+        verbose_name=_("transaction"),
     )
     source_data = JSONField(
-        default=json_default, help_text="Original data received from the data source."
+        default=json_default,
+        help_text="Original data received from the data source.",
+        verbose_name=_("source data"),
     )
 
     objects = StatementLineManager()
@@ -606,7 +698,9 @@ class StatementLine(models.Model):
         Leg.objects.create(
             transaction=transaction, account=from_account, amount=+(self.amount * -1)
         )
-        Leg.objects.create(transaction=transaction, account=to_account, amount=-(self.amount * -1))
+        Leg.objects.create(
+            transaction=transaction, account=to_account, amount=-(self.amount * -1)
+        )
 
         transaction.date = self.date
         transaction.save()
@@ -614,3 +708,6 @@ class StatementLine(models.Model):
         self.transaction = transaction
         self.save()
         return transaction
+
+    class Meta:
+        verbose_name = _("statementLine")
